@@ -58,10 +58,11 @@ class Insert:
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
     """
-    def __init__(self, code_box, position, code):
+    def __init__(self, code_box, position, code, pauses=[]):
         self.code_box = code_box
         self.code = code
         self.position = position
+        self.pauses = pauses
 
     def __str__(self):
         content = condense(self.code.source)
@@ -69,7 +70,31 @@ class Insert:
 
     def steps(self):
         lines = parse_source(self.code.source, self.code.lexer)
-        steps = [steplib.InsertRows(self.code_box, self.position, lines), ]
+        if not self.pauses:
+            # No pauses to insert, insert it all
+            steps = [steplib.InsertRows(self.code_box, self.position, lines), ]
+        else:
+            start = 0
+            steps = []
+
+            for count, pause in enumerate(self.pauses):
+                # Insert everything up to the pause
+                subset = lines[start:pause.line_no]
+                offset = self.position + count
+                step = steplib.InsertRows(self.code_box, offset, subset)
+                steps.append(step)
+
+                # Do the pause by inserting a sleep step
+                steps.append(steplib.Sleep(pause.duration))
+
+                start += len(subset)
+
+            if start < len(lines):
+                # Insert the remainder
+                subset = lines[start:]
+                offset = self.position + count
+                step = steplib.InsertRows(self.code_box, offset, subset)
+                steps.append(step)
 
         return steps
 
@@ -84,8 +109,8 @@ class Append(Insert):
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
     """
-    def __init__(self, code_box, code):
-        super().__init__(code_box, 0, code)
+    def __init__(self, code_box, code, pauses=[]):
+        super().__init__(code_box, 0, code, pauses)
 
     def __str__(self):
         content = condense(self.code.source)
@@ -300,6 +325,7 @@ class TypewriterStep(TypewriterBase):
 
     def steps(self):
         steps = []
+        pauses = {p.line_no:p for p in self.pauses}
 
         lines = parse_source(self.code.source, self.code.lexer)
         for count, line in enumerate(lines):
@@ -311,6 +337,10 @@ class TypewriterStep(TypewriterBase):
                 spot = self.position + count
                 line_steps = self._line_to_steps(line, spot, spot)
 
+            if count in pauses:
+                # Processed line is supposed to have a Pause after it
+                steps.append(steplib.Sleep(pauses[count].duration))
+
             steps.extend(line_steps)
 
         return steps
@@ -327,10 +357,11 @@ class AppendTypewriter(TypewriterStep):
                  code to insert.
     """
 
-    def __init__(self, code_box, code):
+    def __init__(self, code_box, code, pauses=[]):
         self.code_box = code_box
         self.code = code
         self.position = 0
+        self.pauses = pauses
 
     def __str__(self):
         content = condense(self.code.source)
@@ -349,7 +380,7 @@ class InsertTypewriter(TypewriterStep):
     :param code: a :class:`purdy.content.Code` object containing the source
                  code to insert.
     """
-    def __init__(self, code_box, position, code):
+    def __init__(self, code_box, position, code, pauses=[]):
         if position < 0:
             raise AttributeError(
                 'Negative indicies are not supported for this action')
@@ -357,6 +388,7 @@ class InsertTypewriter(TypewriterStep):
         self.code_box = code_box
         self.code = code
         self.position = position
+        self.pauses = pauses
 
     def __str__(self):
         content = condense(self.code.source)
@@ -379,6 +411,7 @@ class SuffixTypewriter(TypewriterBase):
         self.code_box = code_box
         self.position = position
         self.source = source
+        self.pauses = []
 
     def __str__(self):
         return f'actions.SuffixTypewriter({self.position}, "{self.source}")'
@@ -614,3 +647,19 @@ class Section:
 
     def steps(self):
         return [steplib.SectionBreak(), ]
+
+
+class Pause:
+    """Used by some actions to indicate a delay between output lines.
+
+    :param line_no: line in block to insert pause after. Note that this does
+        not differentiate between code and output, just lines in a block
+    :param duartion: time in seconds to delay (ints and floats supported)
+    """
+
+    def __init__(self, line_no, duration):
+        self.line_no = line_no
+        self.duration = duration
+
+    def __str__(self):
+        return f'actions.Pause(line={self.line_no}, amt={self.duration})'
