@@ -10,7 +10,7 @@ class TestExercises(TestCase):
         exercises = ["all_console", "append", "bash_console", "builder", 
             "cols", "compact", "docstring", "exec", "fold", "highlight",
             "insert", "lines", "maxheight", "mixed", "mls_type",
-            "movie_console", "remove", "replace", "section", "sleep", 
+            "movie_console", "pause", "remove", "replace", "section", "sleep", 
             "split_long", "src_change", "swipe", "tall", "triple",
             "type_console", ]
 
